/*
 * Copyright (C) 2008 Luke Kenneth Casson Leighton <lkcl@lkcl.net>
 * Copyright (C) 2008 Alp Toker <alp@atoker.com>
 * Copyright (C) 2008 Apple Inc.
 */

#include "config.h"

#include <wtf/GetPtr.h>
#include "CSSPrimitiveValue.h"
#include "CSSRule.h"
#include "CSSValue.h"
#include "CanvasPixelArray.h"
#include "Counter.h"
#include "DOMWindow.h"
#include "Element.h"
#include "Event.h"
#include "GDOMBinding.h"
#include "GDOMObject.h"
#include "HTMLCollection.h"
#include "Node.h"
#include "Rect.h"
#include "StyleSheet.h"
#include "Text.h"
#include "gdom/GStringConvert.h"
#include "gdom/GdomCSSPrimitiveValue.h"
#include "gdom/GdomCSSValue.h"
#include "gdom/GdomCounter.h"
#include "gdom/GdomRect.h"
#include "gdom/PrivateGdomCSSPrimitiveValue.h"
#include "gdom/PrivateGdomCSSValue.h"
#include "gdom/PrivateGdomCounter.h"
#include "gdom/PrivateGdomDOMObject.h"
#include "gdom/PrivateGdomRect.h"
#include "gdom/PrivateIntGdomCSSPrimitiveValue.h"
#include "gdom/PrivateIntGdomCounter.h"
#include "gdom/PrivateIntGdomRect.h"
#include "glib-object.h"

namespace WebCore {
    gpointer toGDOM(Node* node);
    gpointer toGDOM(CSSValue* node);
    gpointer toGDOM(CSSRule* node);
    gpointer toGDOM(Element* node);
    gpointer toGDOM(Document* node);
    gpointer toGDOM(HTMLCollection* node);
    //gpointer toGDOM(SVGPathSeg* node);
    gpointer toGDOM(StyleSheet* node);
    gpointer toGDOM(EventTargetNode* node);
    gpointer toGDOM(EventTarget* node);
    gpointer toGDOM(Event* node);
    gpointer toGDOM(CanvasPixelArray* node);
    gpointer toGDOM(DOMWindow* node);
    gpointer toGDOM(Text* node);
} // namespace WebCore

namespace WebCore {
} /* namespace WebCore */
extern "C" {

GDOMCSSPrimitiveValue::GDOMCSSPrimitiveValue(PassRefPtr<WebCore::CSSPrimitiveValue> impl)
    : GDOMCSSValue(impl)
{
}

void
gdom_css_primitive_value_set_float_value (GdomCSSPrimitiveValue *thiz, gushort unit_type, gfloat float_value)
{
    g_return_if_fail (thiz);
    WebCore::CSSPrimitiveValue * item = (gdom_css_primitive_value_get_private(thiz));
    g_return_if_fail (item);
    WebCore::ExceptionCode ec = 0;
    item->setFloatValue(unit_type, float_value, ec);

}

gfloat
gdom_css_primitive_value_get_float_value (GdomCSSPrimitiveValue *thiz, gushort unit_type)
{
    g_return_val_if_fail (thiz, 0);
    WebCore::CSSPrimitiveValue * item = (gdom_css_primitive_value_get_private(thiz));
    g_return_val_if_fail (item, 0);
    WebCore::ExceptionCode ec = 0;
    gfloat res = item->getFloatValue(unit_type, ec);
    return res;

}

void
gdom_css_primitive_value_set_string_value (GdomCSSPrimitiveValue *thiz, gushort string_type, gchar * string_value)
{
    g_return_if_fail (thiz);
    WebCore::CSSPrimitiveValue * item = (gdom_css_primitive_value_get_private(thiz));
    g_return_if_fail (item);
    g_return_if_fail (string_value);
    WebCore::String _g_string_value = WebCore::String::fromUTF8(string_value);
    WebCore::ExceptionCode ec = 0;
    item->setStringValue(string_type, _g_string_value, ec);

}

gchar *
gdom_css_primitive_value_get_string_value (GdomCSSPrimitiveValue *thiz)
{
    g_return_val_if_fail (thiz, 0);
    WebCore::CSSPrimitiveValue * item = (gdom_css_primitive_value_get_private(thiz));
    g_return_val_if_fail (item, 0);
    WebCore::ExceptionCode ec = 0;
    gchar * res = _G_GET_UTF8(item->getStringValue(ec));
    return res;

}

GdomCounter *
gdom_css_primitive_value_get_counter_value (GdomCSSPrimitiveValue *thiz)
{
    g_return_val_if_fail (thiz, 0);
    WebCore::CSSPrimitiveValue * item = (gdom_css_primitive_value_get_private(thiz));
    g_return_val_if_fail (item, 0);
    WebCore::ExceptionCode ec = 0;
    PassRefPtr<WebCore::Counter> g_res = WTF::getPtr(item->getCounterValue(ec));
    GdomCounter * res = static_cast<GdomCounter *>(WebCore::toGDOM(g_res.get()));
    return res;

}

GdomRect *
gdom_css_primitive_value_get_rect_value (GdomCSSPrimitiveValue *thiz)
{
    g_return_val_if_fail (thiz, 0);
    WebCore::CSSPrimitiveValue * item = (gdom_css_primitive_value_get_private(thiz));
    g_return_val_if_fail (item, 0);
    WebCore::ExceptionCode ec = 0;
    PassRefPtr<WebCore::Rect> g_res = WTF::getPtr(item->getRectValue(ec));
    GdomRect * res = static_cast<GdomRect *>(WebCore::toGDOM(g_res.get()));
    return res;

}

gulong
gdom_css_primitive_value_get_rgb_color_value (GdomCSSPrimitiveValue *thiz)
{
    g_return_val_if_fail (thiz, 0);
    WebCore::CSSPrimitiveValue * item = (gdom_css_primitive_value_get_private(thiz));
    g_return_val_if_fail (item, 0);
    WebCore::ExceptionCode ec = 0;
    gulong res = item->getRGBColorValue(ec);
    return res;

}

} /* extern "C" */


#include "config.h"
#include "glib-object.h"
#include <webkit/webkitdefines.h>
#include <webkit/webkitprivate.h> 
#include "DOMWindow.h" /* yukk: TODO - make this optional */
#include "Node.h" /* yukk: TODO - make this optional */
#include "NamedNodeMap.h" /* yukk: TODO - make this optional */
#include "CanvasPattern.h" /* yukk: TODO - make this optional */
#include "CanvasGradient.h" /* yukk: TODO - make this optional */
#include "CanvasStyle.h" /* yukk: TODO - make this optional */
#include "CanvasRenderingContext2D.h" /* yukk: TODO - make this optional */
#include <gdom/PrivateGdomDOMObject.h> /* yukk: TODO - make this optional */
#include <gdom/GdomEventTargetNode.h> /* yukk: TODO - make this optional */
#include <gdom/PrivateGdomEventTargetNode.h> /* yukk: TODO - make this optional on EventTarget*/
#include "CSSPrimitiveValue.h"
#include <gdom/GdomCSSPrimitiveValue.h>
#include <gdom/PrivateGdomCSSPrimitiveValue.h>
#include <gdom/PrivateIntGdomCSSPrimitiveValue.h>
#include <gdom/GdomCSSPrimitiveValueprops.h>

#include "gdom/GStringConvert.h"

#include "CanvasPixelArray.h"
#include "Event.h"
#include "Text.h"
#include "CSSValue.h"
#include "CSSRule.h"
#include "HTMLCollection.h"
#include "StyleSheet.h"
#include "Document.h"
#include "webkitmarshal.h"
#include <gdom/GdomEvent.h>



namespace WebCore {
    gpointer toGDOM(Node* node);
    gpointer toGDOM(CSSValue* node);
    gpointer toGDOM(CSSRule* node);
    gpointer toGDOM(Element* node);
    gpointer toGDOM(Document* node);
    gpointer toGDOM(HTMLCollection* node);
    //gpointer toGDOM(SVGPathSeg* node);
    gpointer toGDOM(StyleSheet* node);
    gpointer toGDOM(EventTargetNode* node);
    gpointer toGDOM(EventTarget* node);
    gpointer toGDOM(Event* node);
    gpointer toGDOM(CanvasPixelArray* node);
    gpointer toGDOM(DOMWindow* node);
    gpointer toGDOM(Text* node);
} // namespace WebCore



G_BEGIN_DECLS

G_DEFINE_TYPE(GdomCSSPrimitiveValue, gdom_css_primitive_value, GDOM_TYPE_CSS_VALUE);

/*
struct _GdomCSSPrimitiveValuePrivate {
    class WebCore::CSSPrimitiveValue *item;
};

#define GDOM_CSS_PRIMITIVE_VALUE_GET_PRIVATE(obj) (G_TYPE_INSTANCE_GET_PRIVATE((obj), GDOM_TYPE_CSS_PRIMITIVE_VALUE, GdomCSSPrimitiveValuePrivate))
*/
G_END_DECLS
WebCore::CSSPrimitiveValue *
gdom_css_primitive_value_get_private(GdomCSSPrimitiveValue *request)
{
    GDOMCSSPrimitiveValue *res;
    res = static_cast<GDOMCSSPrimitiveValue*>(gdom_dom_object_get_private(GDOM_DOM_OBJECT(request)));
    return static_cast<WebCore::CSSPrimitiveValue*>(res->impl());
}

G_BEGIN_DECLS

enum {
    BROWSER_EVENT,
    LAST_SIGNAL
};

static guint event_signals[LAST_SIGNAL] = { 0, };

enum {
    PROP_0,
    PROP_PRIMITIVE_TYPE,
};


static void gdom_css_primitive_value_finalize(GObject* object)
{
    /*GdomCSSPrimitiveValue* request = GDOM_CSS_PRIMITIVE_VALUE(object);*/
    /*GdomCSSPrimitiveValuePrivate* priv = request->priv;*/

    /*GObjectClass *parent_class = g_type_class_peek (g_type_peek_parent (GDOM_TYPE_CSS_VALUE));*/

    /* Free any memory or close any files */

    /*parent_class-> finalize (object);*/

    G_OBJECT_CLASS(gdom_css_primitive_value_parent_class)->finalize(object);
}

static void gdom_css_primitive_value__set_property_fn(GObject * object, guint prop_id,
                     const GValue * value,
                     GParamSpec * pspec)
{
    GdomCSSPrimitiveValue *self = GDOM_CSS_PRIMITIVE_VALUE(object);
    WebCore::CSSPrimitiveValue * gself = (gdom_css_primitive_value_get_private(self));
    switch (prop_id) {
    default:
        G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
        break;
    }
}


static void gdom_css_primitive_value__get_property_fn(GObject * object, guint prop_id,
                     GValue * value,
                     GParamSpec * pspec)
{
    GdomCSSPrimitiveValue *self = GDOM_CSS_PRIMITIVE_VALUE(object);
    WebCore::CSSPrimitiveValue * gself = (gdom_css_primitive_value_get_private(self));
    switch (prop_id) {
    case PROP_PRIMITIVE_TYPE:
    {
         g_value_set_uint (value, gself->primitiveType());
         break;
    }
    default:
        G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
        break;
    }
}


static void gdom_css_primitive_value_class_init(GdomCSSPrimitiveValueClass* requestClass)
{
    GObjectClass *g_klass = G_OBJECT_CLASS (requestClass);
    g_klass->finalize = gdom_css_primitive_value_finalize;
    g_klass->set_property = gdom_css_primitive_value__set_property_fn;
    g_klass->get_property = gdom_css_primitive_value__get_property_fn;

    g_object_class_install_property (g_klass, PROP_PRIMITIVE_TYPE,
            g_param_spec_uint ("primitive_type", /* name */
                "css_primitive_value_primitive_type", /* short description */
                "read-only  gushort CSSPrimitiveValue.primitive_type", /* longer - could do with some extra doc stuff here */
                 0,        /* min */
                G_MAXUINT16, /* max */
                0,        /* default */
                 (GParamFlags)G_PARAM_READABLE));





    /*g_type_class_remove_private(requestClass, sizeof(GdomCSSPrimitiveValuePrivate));*/
}

static void gdom_css_primitive_value_init(GdomCSSPrimitiveValue* request)
{
    /*GdomCSSPrimitiveValuePrivate* priv = GDOM_CSS_PRIMITIVE_VALUE_GET_PRIVATE(request);
    request->priv = priv;*/
}

} /* extern "C" */

